/**
 * @file
 * Provides modal feature.
 *
 * The extra line between the end of the @file docblock
 * and the file-closure is important.
 */

'use strict';

(function ($, Drupal, drupalSettings) {
  /**
   * Displays the prehome in a modal.
   *
   * @type {Drupal~behavior}
   *
   * @prop {Drupal~behaviorAttach} attach
   *   Opens the modal.
   */
  Drupal.behaviors.prehomeModal = {
    /**
     * Attach behaviors.
     *
     * @param context
     *   This is the dom element of context.
     */
    attach: function (context) {
      $('.prehome-modal', context).once('prehome-modal').each(function () {
        Drupal.dialog($(this), {
          title: drupalSettings.title,
          classes: {
            'ui-dialog': drupalSettings.classes,
          },
          draggable: false,
          open: function (event, ui) {
            // Close modal on overlay click.
            $(this).parents().attr('tabindex', -1).focus();
            $('.ui-widget-overlay').on('click', function () {
              $('.ui-dialog-titlebar-close').click();
            });
          },
          close: function (event) {
            // Destroy the DOM element that was used for the dialog.
            $(event.target).remove();
          },
        }).showModal();
      });
    }
  };

}(jQuery, Drupal, drupalSettings));
